@@ -81,15 +81,25 @@
 
     By default, TreeView \l {toggleExpanded()}{toggles} the expanded state
     of a row when you double tap on it. Since this is in conflict with
-    double tapping to edit a cell, TreeView sets \l editTriggers to
+    double tapping to edit a cell, TreeView sets \l {TableView::}{editTriggers} to
     \c TableView.EditKeyPressed by default (which is different from TableView,
     which uses \c {TableView.EditKeyPressed | TableView.DoubleTapped}.
-    If you change \l editTriggers to also contain \c TableView.DoubleTapped,
+    If you change \l {TableView::}{editTriggers} to also contain \c TableView.DoubleTapped,
     toggling the expanded state with a double tap will be disabled.
 
     \note A TreeView only accepts a model that inherits \l QAbstractItemModel.
 */
 
+/*!
+    \qmlproperty QModelIndex QtQuick::TreeView::rootIndex
+    \since 6.6
+
+    This property holds the model index of the root item in the tree.
+    By default, this is the same as the root index in the model, but you can
+    set it to be a child index instead, to show only a branch of the tree.
+    Set it to \c undefined to show the whole model.
+*/
+
 /*!
     \qmlmethod int QtQuick::TreeView::depth(row)
 
@@ -268,9 +278,6 @@ void QQuickTreeViewPrivate::setModelImpl(const QVariant &newModel)
 {
     Q_Q(QQuickTreeView);
 
-    if (newModel == m_assignedModel)
-        return;
-
     m_assignedModel = newModel;
     QVariant effectiveModel = m_assignedModel;
     if (effectiveModel.userType() == qMetaTypeId<QJSValue>())
@@ -403,6 +410,8 @@ QQuickTreeView::QQuickTreeView(QQuickItem *parent)
     d->QQuickTableViewPrivate::setModelImpl(modelAsVariant);
     QObjectPrivate::connect(&d->m_treeModelToTableModel, &QAbstractItemModel::dataChanged,
                             d, &QQuickTreeViewPrivate::dataChangedCallback);
+    QObject::connect(&d->m_treeModelToTableModel, &QQmlTreeModelToTableModel::rootIndexChanged,
+                     this, &QQuickTreeView::rootIndexChanged);
 
     auto tapHandler = new QQuickTapHandler(this);
     tapHandler->setAcceptedModifiers(Qt::NoModifier);
@@ -421,6 +430,25 @@ QQuickTreeView::~QQuickTreeView()
 {
 }
 
+QModelIndex QQuickTreeView::rootIndex() const
+{
+    return d_func()->m_treeModelToTableModel.rootIndex();
+}
+
+void QQuickTreeView::setRootIndex(const QModelIndex &index)
+{
+    Q_D(QQuickTreeView);
+    d->m_treeModelToTableModel.setRootIndex(index);
+    positionViewAtCell({0, 0}, QQuickTableView::AlignTop | QQuickTableView::AlignLeft);
+}
+
+void QQuickTreeView::resetRootIndex()
+{
+    Q_D(QQuickTreeView);
+    d->m_treeModelToTableModel.resetRootIndex();
+    positionViewAtCell({0, 0}, QQuickTableView::AlignTop | QQuickTableView::AlignLeft);
+}
+
 int QQuickTreeView::depth(int row) const
 {
     Q_D(const QQuickTreeView);
